from setuptools import setup

setup(name='distributions_Statistics',
      version='0.1',
      description='Gaussian distributions',
      packages=['distributions_Statistics'],
      author='Kaan Mavice',
      author_email='kaan.mavice@gmail.com',
      zip_safe=False)
